@@ -20,6 +20,7 @@ class Analyser(object):
     self._data = {
         'book': None,
         'fill': None,
+        'order': None,
         'balance': None,
         'pnl_balance': None,
         'position': None,
@@ -56,21 +57,26 @@ class Analyser(object):
     return self._symbol_list
 
   def plot_fill(self, symbol):
+    simple_symbol = symbol.split('.')[0]
+
     fill_df = self._data['fill']
     book_df = self._data['book']
+    order_df = self._data['order']
 
     book_df = book_df[book_df.symbol == symbol]
-    prod_df = fill_df[fill_df.symbol == symbol.split('.')[0]]
 
-    buy_df = prod_df[prod_df.fill_qty > 0]
-    sell_df = prod_df[prod_df.fill_qty < 0]
+    fill_df = fill_df[fill_df.symbol == simple_symbol]
+    buy_df = fill_df[fill_df.fill_qty > 0]
+    sell_df = fill_df[fill_df.fill_qty < 0]
+
+    order_df = order_df[order_df.symbol == simple_symbol]
 
     plt.figure()
     ax0 = plt.subplot(211)
     plt.title(symbol)
     # book
-    ax0.plot(book_df.timestamp, book_df.ask0_price, color='lightpink', marker='.', alpha=0.1)
-    ax0.plot(book_df.timestamp, book_df.bid0_price, color='palegreen', marker='.', alpha=0.1)
+    ax0.plot(book_df.timestamp, book_df.ask0_price, color='lightpink', marker='.', alpha=0.3)
+    ax0.plot(book_df.timestamp, book_df.bid0_price, color='palegreen', marker='.', alpha=0.3)
 
     # avg buy/sell price
     avg_sell_price = (sell_df.fill_price * sell_df.fill_qty.abs()).cumsum() / sell_df.fill_qty.abs().cumsum()
@@ -78,17 +84,23 @@ class Analyser(object):
     ax0.plot(sell_df.timestamp, avg_sell_price, alpha=0.4, color='lightpink')
     ax0.plot(buy_df.timestamp, avg_buy_price, alpha=0.4, color='palegreen')
 
-    # buy/sell price
-    ax0.plot(sell_df.timestamp, sell_df.fill_price, color='red', marker='.')
-    ax0.plot(buy_df.timestamp, buy_df.fill_price, color='blue', marker='.')
+    # order
+    sell_order_df = order_df[order_df.order_qty < 0]
+    buy_order_df = order_df[order_df.order_qty > 0]
+    ax0.plot(sell_order_df.timestamp, sell_order_df.order_price, color='brown', marker='.', alpha=0.4)
+    ax0.plot(buy_order_df.timestamp, buy_order_df.order_price, color='black', marker='.', alpha=0.4)
 
-    # PNL
+    # fill buy/sell price
+    ax0.plot(sell_df.timestamp, sell_df.fill_price, color='red', marker='v')
+    ax0.plot(buy_df.timestamp, buy_df.fill_price, color='blue', marker='^')
+
+    # pnl
     ax1 = ax0.twinx()
-    pnl = -(prod_df.fill_price * prod_df.fill_qty).cumsum() + prod_df.fill_qty.cumsum() * prod_df.fill_price
-    ax1.plot(prod_df.timestamp, pnl)
+    pnl = -(fill_df.fill_price * fill_df.fill_qty).cumsum() + fill_df.fill_qty.cumsum() * fill_df.fill_price
+    ax1.plot(fill_df.timestamp, pnl)
 
     ax2 = plt.subplot(212, sharex=ax0)
-    ax2.plot(prod_df.timestamp, prod_df.fill_qty.cumsum())
+    ax2.plot(fill_df.timestamp, fill_df.fill_qty.cumsum())
 
     plt.show()
 
